@@ -10,9 +10,17 @@ class Language(object):
         self.translator = locate('mlc_tools.%s.Translator' % module_name)()
         self.serializer = locate('mlc_tools.%s.Serializer' % module_name)()
         self.writer = locate('mlc_tools.%s.Writer' % module_name)(model.out_directory)
+        self.save_plugin = locate('mlc_tools.%s.SavePlugin' % module_name)(model)
         self.writer.model = model
         self.writer.serializer = self.serializer
 
+        try:
+            self.registrar = locate('mlc_tools.%s.registrar' % module_name).Registrar()
+        except AttributeError:
+            self.registrar = None
+        except TypeError:
+            self.registrar = None
+
     def get_generator(self):
         return self.generator
 
