@@ -15,7 +15,7 @@ class Parser(object):
 
     def parse_files(self, files):
         for path in files:
-            text = open(path).read()
+            text = open(path, encoding='utf-8').read()
             self.parse_text(text)
 
     def parse_text(self, text):
@@ -27,6 +27,8 @@ class Parser(object):
                 text = self._create_class(text, True)
             elif Parser._is_enum(text):
                 text = self._create_enum_class(text)
+            elif Parser._is_include(text):
+                text = self._create_include(text)
             elif Parser._is_function(text):
                 text = self._create_function(text)
             elif Parser._is_constructor(text):
@@ -126,6 +128,14 @@ class Parser(object):
             self.model.objects.append(obj)
         return text
 
+    def _create_include(self, text):
+        k = text.find('\n')
+        line = text[0:k]
+        text = text[k+1:]
+        class_name = line.replace('@include ', '').strip()
+        self.model.includes.add(class_name)
+        return text
+
     def _create_function(self, text):
         body, header, text = Parser.parse_body(text)
         skip, header = self.check_skip(header)
@@ -275,6 +285,10 @@ class Parser(object):
     def _is_constructor(line):
         return line.find('constructor') == 0
 
+    @staticmethod
+    def _is_include(line):
+        return line.startswith('@include')
+
     @staticmethod
     def _is_enum(line):
         return line.find('enum') == 0
@@ -351,11 +365,11 @@ class Parser(object):
         in_serialize = False
         in_initial_value = initial_value is None
         pattern = []
-        if type_object in ['int64_t', 'uint', 'uint64_t']:
+        if type_object in ['int64_t', 'uint', 'uint64_t', 'unsigned']:
             type_object = 'int'
         if type_object in ['double']:
             type_object = 'float'
-        if type_object in ['list<int64_t>', 'list<uint>', 'list<uint64_t>']:
+        if type_object in ['list<int64_t>', 'list<uint>', 'list<uint64_t>', 'list<unsigned>']:
             type_object = 'list<int>'
         if type_object in ['list<double>']:
             type_object = 'list<float>'
@@ -479,6 +493,8 @@ class Parser(object):
 
         cls.members = self.model.objects
         cls.functions = self.model.functions
+        cls.user_includes = self.model.includes
+        self.model.includes = set()
 
         for member in cls.members:
             member.set_default_initial_value()
\ No newline at end of file
