@@ -127,10 +127,12 @@ class Console(object):
                              generate_factory=self.config.features.get(Feature.FACTORY, True),
                              generate_tests=self.config.features.get(Feature.GENERATE_TESTS, False),
                              language=self.config.lang,
-                             php_validate=self.config.features.get(Feature.PHP_VALIDATE, True),
+                             php_validate=self.config.features.get(Feature.PHP_VALIDATE, False),
                              join_to_one_file=True,
                              auto_registration=self.config.features.get(Feature.AUTO_REGISTRATION, False),
-                             formats=self.config.serialize_format)
+                             formats=self.config.serialize_format,
+                             add_config=self.config.src_directory_add
+                             )
 
         self.generator.generate()
         if os.path.isdir(self.generator.model.data_directory):
@@ -186,8 +188,14 @@ class Console(object):
         if process.call() != 0:
             raise RuntimeError('Error on cmake')
 
-        process = SubprocessWrapper(f'make -j4 -C {self.config.build_directory}')
-        if process.call() != 0:
+        process = SubprocessWrapper(f'make -j4 -C {self.config.build_directory}', require_out=True)
+        code, out, err = process.call()
+        if code != 0:
+            print('----\nmake Out:\n----')
+            print(out)
+            print('----\nmake Err:\n----')
+            print(err)
+            print('----\nEnd make log:\n----')
             raise RuntimeError('Error on make')
 
     def _run(self):
