@@ -8,6 +8,8 @@ from ..utils.error import Error
 
 class Class(Object):
 
+    OPERATOR_MATCH = re.compile(r'operator\b.+')
+
     def __init__(self, name=''):
         Object.__init__(self)
         self.superclasses = []
@@ -15,6 +17,7 @@ class Class(Object):
         self.constructor = None
         self.members = []
         self.functions = []
+        self.user_includes = set()
         self.is_abstract = False
         self.is_serialized = False
         self.is_visitor = False
@@ -30,6 +33,7 @@ class Class(Object):
         self.auto_generated = True
         self.inner_classes = []
         self._linked = False
+        self.prefer_use_forward_declarations = False
 
         self.name = name
 
@@ -74,7 +78,9 @@ class Class(Object):
                 func.is_virtual or \
                 func.is_abstract or \
                 self.has_function_in_subclasses(func)
-            if 'operator' in func.name:
+
+            # if 'operator' in func.name:
+            if Class.OPERATOR_MATCH.findall(func.name):
                 func.is_virtual = False
             func.is_virtual = func.is_virtual or \
                 self.has_function_in_superclasses(func)
@@ -100,9 +106,9 @@ class Class(Object):
                 if equal:
                     func.is_virtual = True
                     return True
-        for cls in list_of_classes:
-            if cls.has_function_in_subclasses(method):
-                return True
+        # for cls in list_of_classes:
+        #     if cls.has_function_in_subclasses(method):
+        #         return True
         return False
 
 
@@ -122,6 +128,8 @@ class Class(Object):
         self.is_inline = self.is_inline or Modifiers.inline in string
         self.is_virtual = self.is_virtual or Modifiers.virtual in string
         self.generate_set_function = self.generate_set_function or Modifiers.set_function in string
+        self.prefer_use_forward_declarations = self.prefer_use_forward_declarations or Modifiers.prefer_use_forward_declarations in string
+
         if Modifiers.server in string:
             self.side = Modifiers.side_server
         if Modifiers.client in string:
@@ -138,6 +146,8 @@ class Class(Object):
         string = string.replace(Modifiers.test, '')
         string = string.replace(Modifiers.inline, '')
         string = string.replace(Modifiers.virtual, '')
+        string = string.replace(Modifiers.prefer_use_forward_declarations, '')
+
         return string
 
     def generate_constructor(self):
