@@ -37,6 +37,8 @@ class Mlc(object):
         self.model.namespace = kwargs.get('namespace', self.model.namespace)
         self.model.side = kwargs.get('side', self.model.side)
         self.model.php_validate = kwargs.get('php_validate', self.model.php_validate)
+        self.model.validate_allow_different_virtual_method = kwargs.get('validate_allow_different_virtual_method',
+                                                             self.model.validate_allow_different_virtual_method)
         self.model.test_script = kwargs.get('test_script', self.model.test_script)
         self.model.test_script_args = kwargs.get('test_script_args', self.model.test_script_args)
         self.model.generate_tests = kwargs.get('generate_tests', self.model.generate_tests)
@@ -48,7 +50,9 @@ class Mlc(object):
         self.model.join_to_one_file = kwargs.get('join_to_one_file', self.model.join_to_one_file)
         self.model.auto_registration = kwargs.get('auto_registration', self.model.auto_registration)
         self.model.generate_ref_counter = kwargs.get('generate_ref_counter', self.model.generate_ref_counter)
-        if 'add_config' in kwargs:
+        self.model.user_includes = kwargs.get('user_includes', self.model.user_includes)
+        self.model.empty_methods = kwargs.get('empty_methods', self.model.empty_methods)
+        if 'add_config' in kwargs and kwargs.get('add_config') is not None:
             directory = fileutils.normalize_path(kwargs.get('add_config'))
             self.model.additional_config_directories.append(directory)
         if 'add_data' in kwargs:
