@@ -1,7 +1,10 @@
 import re
 from ..base import WriterBase
+from ..core.class_ import Class
+from ..core.function import Function
 from ..core.object import Object, AccessSpecifier
 from .regex import RegexPatternCpp
+from ..utils.error import Error
 
 
 class Writer(WriterBase):
@@ -28,6 +31,10 @@ class Writer(WriterBase):
 
         header, includes, forward_declarations, forward_declarations_out = self.write_hpp(cls)
         source = self.write_cpp(cls, includes, forward_declarations, forward_declarations_out)
+
+        if self.model.custom_generator:
+            header, source = self.model.custom_generator.modify_sources(self.model, cls, header, source)
+
         return [
             (self.get_filename(cls, 'h'), self.prepare_file(header)),
             (self.get_filename(cls, 'cpp'), self.prepare_file(source)),
@@ -176,12 +183,49 @@ class Writer(WriterBase):
         args = ', '.join(args)
         return args
 
+    def is_overrides(self, method: Function):
+        if not method.is_virtual:
+            return False
+        superclass: Class = self.current_class.superclasses[0] if self.current_class.superclasses else None
+        allowed = ['visit']
+        while superclass is not None:
+            for function in superclass.functions:
+                if function.name != method.name:
+                    continue
+                if function.return_type.type != method.return_type.type:
+                    if not self.model.validate_allow_different_virtual_method:
+                        Error.exit(Error.ERROR_VIRTUAL_METHOD_HAS_DIFFERENT_DECLARATION, self.current_class.name,
+                                   method.name, superclass.name)
+                    continue
+
+                if len(function.args) != len(method.args):
+                    if not self.model.validate_allow_different_virtual_method and method.name not in allowed:
+                        Error.exit(Error.ERROR_VIRTUAL_METHOD_HAS_DIFFERENT_DECLARATION, self.current_class.name,
+                                   method.name, superclass.name)
+                    continue
+                cont = False
+                for i, args in enumerate(function.args):
+                    if args[1].type != method.args[i][1].type:
+                        if not self.model.validate_allow_different_virtual_method and method.name not in allowed:
+                            Error.exit(Error.ERROR_VIRTUAL_METHOD_HAS_DIFFERENT_DECLARATION, self.current_class.name,
+                                       method.name, superclass.name)
+                        cont = True
+                        break
+                if cont:
+                    continue
+                return True
+
+            superclass = superclass.superclasses[0] if superclass.superclasses else None
+        return False
+
     def write_function_hpp(self, method):
         string = '{virtual}{static}{friend}{type} {name}({args}){const}{override}{abstract}'
         assert isinstance(method.return_type, Object)
-        return_type = self.write_named_object(method.return_type, '', False, True)
+        return_type = self.write_named_object(method.return_type, '', False, True) if method.name != self.current_class.name else ''
         args = self.create_function_hpp_args_string(method)
         virtual = 'virtual ' if method.is_virtual or method.is_abstract or self.current_class.is_virtual else ''
+        if method.name == self.current_class.name:
+            virtual = ''
 
         body = ''
         if method.template_types:
@@ -198,12 +242,14 @@ class Writer(WriterBase):
         else:
             string += ';\n'
 
+        is_overrides = self.is_overrides(method)
+
         return string.format(virtual=virtual,
                              static='static ' if method.is_static else '',
                              friend='friend ' if method.is_friend else '',
                              const=' const' if method.is_const else '',
                              abstract=' = 0' if method.is_abstract else '',
-                             override='',
+                             override=' override' if is_overrides else '',
                              type=return_type,
                              name=method.name,
                              args=args,
@@ -232,7 +278,8 @@ class Writer(WriterBase):
         }}
         
         '''
-        return_type = self.write_named_object(method.return_type, '', False, True)
+        return_type = self.write_named_object(method.return_type, '', False,
+                                              True) if method.name != self.current_class.name else ''
         args = self.create_function_cpp_args_string(method)
 
         body = method.body
@@ -413,15 +460,20 @@ class Writer(WriterBase):
 
         # members
         for member in cls.members:
-            def parse_object(obj):
-                add(includes, obj)
+            def parse_object(container, obj):
+                add(container, obj)
                 for arg in obj.template_args:
-                    parse_object(arg)
-
-            parse_object(member)
+                    if cls.name == 'DataStorage' or cls.prefer_use_forward_declarations:
+                        parse_object(forward_declarations, arg)
+                    else:
+                        parse_object(container, arg)
+            parse_object(includes, member)
+            if 'std::atomic' in member.type:
+                includes.add('std::atomic')
 
         # functions
         std_includes = ['map', 'list', 'string']
+        mg_extensions = ['in_list', 'in_map']
         for method in cls.functions:
             for _, argtype in method.args:
                 if argtype.type in std_includes:
@@ -430,7 +482,16 @@ class Writer(WriterBase):
                     add(forward_declarations_out, argtype)
                 else:
                     add(forward_declarations, argtype)
-            add(includes, method.return_type)
+            if not self.model.user_includes or method.return_type.type in std_includes:
+                add(includes, method.return_type)
+            else:
+                add(forward_declarations, method.return_type)
+
+            if method.template_types or method.is_template:
+                for func in mg_extensions:
+                    for line in method.operations:
+                        if func in line:
+                            includes.add('mg_extensions')
 
         # superclasses
         for superclass in cls.superclasses:
@@ -445,13 +506,14 @@ class Writer(WriterBase):
 
         return includes, forward_declarations, forward_declarations_out
 
-    def get_includes_for_source(self, cls, functions_text, hpp_includes, forw_declarations, forw_declarations_out):
+    def get_includes_for_source(self, cls: Class, functions_text, hpp_includes, forw_declarations, forw_declarations_out):
         includes = set()
         includes.add(cls.name)
         includes.update(forw_declarations)
         includes.update(forw_declarations_out)
 
         includes.update(self.get_includes_for_method(cls, functions_text, hpp_includes))
+        includes.update(cls.user_includes)
 
         return self.build_includes(cls, includes)
 
@@ -475,6 +537,7 @@ class Writer(WriterBase):
     def build_includes(self, cls, includes):
         types = {
             'std::list': '<vector>',
+            'std::atomic': '<atomic>',
             'std::vector': '<vector>',
             'std::map': '<map>',
             'std::set': '<set>',
@@ -483,6 +546,7 @@ class Writer(WriterBase):
             'pugi::xml_node': '"pugixml/pugixml.hpp"',
             'Observer': '"Observer.h"',
             'intrusive_ptr': '"intrusive_ptr.h"',
+            'mg_extensions': '"mg_extensions.h"',
         }
         result = []
         for typename in includes:
@@ -496,6 +560,7 @@ class Writer(WriterBase):
                 include = '#include '
                 include += self.get_include_path_to_class(cls, other_class)
                 result.append(include)
+
         result = sorted(result)
         return '\n'.join(result)
 
@@ -526,6 +591,7 @@ class Writer(WriterBase):
             'bool',
             'float',
             'void',
+            'Observable',
         ]
         predefined = {
             'Json::Value': 'namespace Json\n{\nclass Value;\n}\n',
